pub struct TreeNode<T: Ord + Copy + Debug + Display> {
pub value: T,
/* private fields */
}Expand description
Node struct for AVLTree
Fields
value: TTrait Implementations
Sourceimpl<T: Ord + Copy + Debug + Display> CommonTreeNodeTrait<T> for TreeNode<T>
impl<T: Ord + Copy + Debug + Display> CommonTreeNodeTrait<T> for TreeNode<T>
Sourcefn get_value_to_print(&self) -> String
fn get_value_to_print(&self) -> String
Get value string from current node
Sourcefn count_leaves(&self) -> u32
fn count_leaves(&self) -> u32
Return the leaves number of current node, which will be called by
CommonTreeTrait.count_leaves
Sourcefn get_height(&self) -> u32
fn get_height(&self) -> u32
Return the height of current node, which will be called by
CommonTreeTrait.height
Sourcefn in_order_traversal(&self)
fn in_order_traversal(&self)
Print nodes inorder, which will be called by
CommonTreeTrait.in_order_traversal
fn in_order_traversal_for_test(&self, container: &mut Vec<T>)
Sourcefn pre_order_traversal(&self)
fn pre_order_traversal(&self)
Print nodes preorder, which will be called by
CommonTreeTrait.pre_order_traversal
fn pre_order_traversal_for_test(&self, container: &mut Vec<T>)
Sourcefn contains(&self, value: T) -> bool
fn contains(&self, value: T) -> bool
Determine whether the node and its successors contains given value,
which will be called by
CommonTreeTrait.contains
fn get_min_value_in_children(&self) -> T
fn get_max_value_in_children(&self) -> T
fn print(&self)
fn print_helper( &self, row_index: usize, column_index: usize, container: &mut [&mut [String]], height: usize, )
Sourceimpl<T: Ord + Copy + Debug + Display> CommonTreeTrait<T, TreeNode<T>> for AVLTree<T>
impl<T: Ord + Copy + Debug + Display> CommonTreeTrait<T, TreeNode<T>> for AVLTree<T>
fn get_root(&self) -> Option<Rc<RefCell<TreeNode<T>>>>
Sourcefn count_leaves(&self) -> u32
fn count_leaves(&self) -> u32
Counts leaves(None nodes) of the Tree Read more
Sourcefn in_order_traversal(&self)
fn in_order_traversal(&self)
Prints Tree inorder Read more
fn in_order_traversal_for_test(&self, container: &mut Vec<T>)
Sourcefn pre_order_traversal(&self)
fn pre_order_traversal(&self)
Prints red-black tree preorder Read more
fn pre_order_traversal_for_test(&self, container: &mut Vec<T>)
Sourcefn contains(&self, value: T) -> bool
fn contains(&self, value: T) -> bool
Determine whether the tree contains given value Read more
fn is_tree_empty(&self) -> bool
fn min(&self) -> Option<T>
fn max(&self) -> Option<T>
fn print(&self)
Sourceimpl<T: PartialEq + Ord + Copy + Debug + Display> PartialEq for TreeNode<T>
impl<T: PartialEq + Ord + Copy + Debug + Display> PartialEq for TreeNode<T>
impl<T: Ord + Copy + Debug + Display> StructuralPartialEq for TreeNode<T>